@@ -168,7 +168,7 @@ class BERTScorer:
             for cand, ref_group in zip(ori_cands, ori_refs):
                 cands += [cand] * len(ref_group)
                 refs += ref_group
-                ref_group_boundaries.append((count, len(ref_group)))
+                ref_group_boundaries.append((count, count + len(ref_group)))
                 count += len(ref_group)
 
         if verbose:
@@ -279,4 +279,4 @@ class BERTScorer:
         return f'{self.__class__.__name__}(hash={self.hash}, batch_size={self.batch_size}, nthreads={self.nthreads})'
 
     def __str__(self):
-        return self.__repr__()
\ No newline at end of file
+        return self.__repr__()
